@@ -1203,6 +1203,9 @@ class yank(commands.Command):
 		"cwd" : "get_cwd",
 		"type" : "get_type",
 		"last search term" : "get_last_search_term",
+		"path" : "get_rel_path",
+		"relative path" : "get_rel_path",
+		"absolute path" : "get_abs_path",
 	}
 
 	@classmethod
@@ -1315,6 +1318,15 @@ class yank(commands.Command):
 			raise ErrorInCommand(_("nothing has been searched for yet"))
 		return self.app.search_edit.get_last_input()
 
+	def get_rel_path(self, hash_id, type_id):
+		return self.app.get_current_file_path()
+
+	def get_abs_path(self, hash_id, type_id):
+		fn = self.app.get_current_file_path()
+		if fn:
+			fn = os.path.abspath(fn)
+		return fn
+
 
 	# ------- copy -------
 
