@@ -1063,15 +1063,15 @@ class DetailsModel(Model):
 		else:
 			t.append((_("Author"), align_char + author))
 
-		if author_date == committer_date:
-			t.append((_("Date"), align_char + author_date))
-		else:
+		if author_date != committer_date:
 			t.append((_("Author Date"), align_char + author_date))
 
 		if committer != author:
 			t.append((_("Committer"), align_char + committer))
 
-		if committer_date != author_date:
+		if committer_date == author_date:
+			t.append((_("Date"), align_char + author_date))
+		else:
 			t.append((_("Committer Date"), align_char + committer_date))
 
 		for ln in utils.format_table(t, fmt=['%s:']):
